@@ -1,6 +1,5 @@
 """Contains the BackgroundRenderer class."""
 import numpy as np
-import vtk
 
 import pyvista
 from .renderer import Renderer
@@ -11,6 +10,9 @@ class BackgroundRenderer(Renderer):
 
     def __init__(self, parent, image_path, scale=1, view_port=None):
         """Initialize BackgroundRenderer with an image."""
+        # avoiding circular import
+        from pyvista import _vtk
+
         # read the image first as we don't need to create a render if
         # the image path is invalid
         image_data = pyvista.read(image_path)
@@ -26,10 +28,11 @@ class BackgroundRenderer(Renderer):
             self.SetViewport(view_port)
 
         # create image actor
-        image_actor = vtk.vtkImageActor()
+        image_actor = _vtk.vtkImageActor()
         image_actor.SetInputData(image_data)
         self.add_actor(image_actor, name='background')
-        self.camera.ParallelProjectionOn()
+        self.camera.enable_parallel_projection()
+        self.reset_camera()  # necessary to get first render
         self.resize()
 
     def resize(self, *args):
@@ -48,12 +51,12 @@ class BackgroundRenderer(Renderer):
         xc = origin[0] + 0.5*(extent[0] + extent[1]) * spacing[0]
         yc = origin[1] + 0.5*(extent[2] + extent[3]) * spacing[1]
         yd = (extent[3] - extent[2] + 1) * spacing[1]
-        d = self.camera.GetDistance()
+        dist = self.camera.distance
 
         # make the longest dimensions match the plotting window
         img_dim = np.array(image_data.dimensions[:2])
-        self.camera.SetFocalPoint(xc, yc, 0.0)
-        self.camera.SetPosition(xc, yc, d)
+        self.camera.focus = np.array([xc, yc, 0.0])
+        self.camera.position = np.array([xc, yc, dist])
 
         ratio = img_dim/np.array(self.parent.window_size)
         scale_value = 1
@@ -64,4 +67,4 @@ class BackgroundRenderer(Renderer):
         if self._scale is not None:
             scale_value /= self._scale
 
-        self.camera.SetParallelScale(0.5 * yd / self._scale)
+        self.camera.parallel_scale = 0.5 * yd / self._scale
