@@ -1,8 +1,9 @@
 """PyVista Scalar bar module."""
 
+import pyvista
 import numpy as np
 from pyvista import _vtk
-from .theme import parse_font_family, parse_color, rcParams
+from .tools import parse_font_family, parse_color
 
 
 class ScalarBars():
@@ -27,12 +28,34 @@ class ScalarBars():
         """Nice representation of this class."""
         lines = []
         lines.append('Scalar Bar Title     Interactive')
-        for title, actor in self._scalar_bar_actors.items():
+        for title in self._scalar_bar_actors:
             interactive = title in self._scalar_bar_widgets
             title = f'"{title}"'
             lines.append(f'{title:20} {str(interactive):5}')
         return '\n'.join(lines)
 
+    def _remove_mapper_from_plotter(self, actor, reset_camera=False, render=False):
+        """Remove an actor's mapper from the given plotter's _scalar_bar_mappers."""
+        try:
+            mapper = actor.GetMapper()
+        except AttributeError:
+            return
+        for name in list(self._scalar_bar_mappers):
+            try:
+                self._scalar_bar_mappers[name].remove(mapper)
+            except ValueError:
+                pass
+            if not self._scalar_bar_mappers[name]:
+                slot = self._plotter._scalar_bar_slot_lookup.pop(name, None)
+                if slot is not None:
+                    self._scalar_bar_mappers.pop(name)
+                    self._scalar_bar_ranges.pop(name)
+                    self._plotter.remove_actor(self._scalar_bar_actors.pop(name),
+                                               reset_camera=reset_camera,
+                                               render=render)
+                    self._plotter._scalar_bar_slots.add(slot)
+            return
+
     def remove_scalar_bar(self, title=None, render=True):
         """Remove a scalar bar.
 
@@ -103,14 +126,14 @@ class ScalarBars():
 
         Parameters
         ----------
-        mapper : vtkMapper, optional
-            Mapper used for the scalar bar.  Defaults to the last
-            mapper created by the plotter.
-
         title : string, optional
             Title of the scalar bar.  Default ``''`` which is
             rendered as an empty title.
 
+        mapper : vtkMapper, optional
+            Mapper used for the scalar bar.  Defaults to the last
+            mapper created by the plotter.
+
         n_labels : int, optional
             Number of labels to use for the scalar bar.
 
@@ -121,59 +144,73 @@ class ScalarBars():
             Bolds title and bar labels.  Default True
 
         title_font_size : float, optional
-            Sets the size of the title font.  Defaults to None and is sized
-            automatically.
+            Sets the size of the title font.  Defaults to ``None`` and is sized
+            according to ``pyvista.global_theme``.
 
         label_font_size : float, optional
-            Sets the size of the title font.  Defaults to None and is sized
-            automatically.
+            Sets the size of the title font.  Defaults to ``None`` and is sized
+            according to ``pyvista.global_theme``.
 
-        color : string or 3 item list, optional, defaults to white
-            Either a string, rgb list, or hex color string.  For example:
+        color : string or 3 item list, optional
+            Either a string, rgb list, or hex color string.  Defaults to white.
+            For example:
 
             * ``color='white'``
             * ``color='w'``
             * ``color=[1, 1, 1]``
             * ``color='#FFFFFF'``
 
-        font_family : string, optional
-            Font family.  Must be either courier, times, or arial.
+        font_family : {'courier', 'times', 'arial'}
+            Font family.  Default is set by ``pyvista.global_theme``.
 
         shadow : bool, optional
-            Adds a black shadow to the text.  Defaults to False
+            Adds a black shadow to the text.  Defaults to ``False``.
 
         width : float, optional
-            The percentage (0 to 1) width of the window for the colorbar
+            The percentage (0 to 1) width of the window for the colorbar.
+            Default set by ``pyvista.global_theme``.
 
         height : float, optional
-            The percentage (0 to 1) height of the window for the colorbar
+            The percentage (0 to 1) height of the window for the colorbar.
+            Default set by ``pyvista.global_theme``.
 
         position_x : float, optional
             The percentage (0 to 1) along the windows's horizontal
-            direction to place the bottom left corner of the colorbar
+            direction to place the bottom left corner of the colorbar.
+            Default is automatic placement.
 
         position_y : float, optional
             The percentage (0 to 1) along the windows's vertical
-            direction to place the bottom left corner of the colorbar
+            direction to place the bottom left corner of the colorbar.
+            Default is automatic placement.
+
+        vertical : bool, optional
+            Use vertical or horizontal scalar bar.
+            Default set by ``pyvista.global_theme``.
 
         interactive : bool, optional
             Use a widget to control the size and location of the scalar bar.
+            Default set by ``pyvista.global_theme``.
+
+        fmt : str, optional
+            ``printf`` format for labels.
+            Default set by ``pyvista.global_theme``.
 
         use_opacity : bool, optional
-            Optionally display the opacity mapping on the scalar bar
+            Optionally display the opacity mapping on the scalar bar.
 
         outline : bool, optional
             Optionally outline the scalar bar to make opacity mappings more
             obvious.
 
         nan_annotation : bool, optional
-            Annotate the NaN color
+            Annotate the NaN color.
 
         below_label : str, optional
-            String annotation for values below the scalars range
+            String annotation for values below the scalars range.
 
         above_label : str, optional
-            String annotation for values above the scalars range
+            String annotation for values above the scalars range.
 
         background_color : array, optional
             The color used for the background in RGB format.
@@ -181,9 +218,9 @@ class ScalarBars():
         n_colors : int, optional
             The maximum number of color displayed in the scalar bar.
 
-        fill : bool
+        fill : bool, optional
             Draw a filled box behind the scalar bar with the
-            ``background_color``
+            ``background_color``.
 
         render : bool, optional
             Force a render when True.  Default ``True``.
@@ -211,32 +248,32 @@ class ScalarBars():
             raise ValueError('Mapper cannot be ``None`` when creating a scalar bar')
 
         if interactive is None:
-            interactive = rcParams['interactive']
+            interactive = pyvista.global_theme.interactive
         if font_family is None:
-            font_family = rcParams['font']['family']
+            font_family = pyvista.global_theme.font.family
         if label_font_size is None:
-            label_font_size = rcParams['font']['label_size']
+            label_font_size = pyvista.global_theme.font.label_size
         if title_font_size is None:
-            title_font_size = rcParams['font']['title_size']
+            title_font_size = pyvista.global_theme.font.title_size
         if color is None:
-            color = rcParams['font']['color']
+            color = pyvista.global_theme.font.color
         if fmt is None:
-            fmt = rcParams['font']['fmt']
+            fmt = pyvista.global_theme.font.fmt
         if vertical is None:
-            if rcParams['colorbar_orientation'].lower() == 'vertical':
+            if pyvista.global_theme.colorbar_orientation.lower() == 'vertical':
                 vertical = True
 
         # Automatically choose size if not specified
         if width is None:
             if vertical:
-                width = rcParams['colorbar_vertical']['width']
+                width = pyvista.global_theme.colorbar_vertical.width
             else:
-                width = rcParams['colorbar_horizontal']['width']
+                width = pyvista.global_theme.colorbar_horizontal.width
         if height is None:
             if vertical:
-                height = rcParams['colorbar_vertical']['height']
+                height = pyvista.global_theme.colorbar_vertical.height
             else:
-                height = rcParams['colorbar_horizontal']['height']
+                height = pyvista.global_theme.colorbar_horizontal.height
 
         # Check that this data hasn't already been plotted
         if title in list(self._scalar_bar_ranges.keys()):
@@ -267,16 +304,16 @@ class ScalarBars():
                 raise RuntimeError('Maximum number of color bars reached.')
             if position_x is None:
                 if vertical:
-                    position_x = rcParams['colorbar_vertical']['position_x']
+                    position_x = pyvista.global_theme.colorbar_vertical.position_x
                     position_x -= slot * (width + 0.2 * width)
                 else:
-                    position_x = rcParams['colorbar_horizontal']['position_x']
+                    position_x = pyvista.global_theme.colorbar_horizontal.position_x
 
             if position_y is None:
                 if vertical:
-                    position_y = rcParams['colorbar_vertical']['position_y']
+                    position_y = pyvista.global_theme.colorbar_vertical.position_y
                 else:
-                    position_y = rcParams['colorbar_horizontal']['position_y']
+                    position_y = pyvista.global_theme.colorbar_horizontal.position_y
                     position_y += slot * height
 
         # parse color
