@@ -2,101 +2,107 @@
 
 import pathlib
 import os
+import warnings
 
 import numpy as np
-import vtk
 
 import pyvista
-
-VTK9 = vtk.vtkVersion().GetVTKMajorVersion() >= 9
+from pyvista import _vtk
 
 READERS = {
     # Standard dataset readers:
-    '.vtk': vtk.vtkDataSetReader,
-    '.pvtk': vtk.vtkPDataSetReader,
-    '.vti': vtk.vtkXMLImageDataReader,
-    '.pvti': vtk.vtkXMLPImageDataReader,
-    '.vtr': vtk.vtkXMLRectilinearGridReader,
-    '.pvtr': vtk.vtkXMLPRectilinearGridReader,
-    '.vtu': vtk.vtkXMLUnstructuredGridReader,
-    '.pvtu': vtk.vtkXMLPUnstructuredGridReader,
-    '.ply': vtk.vtkPLYReader,
-    '.obj': vtk.vtkOBJReader,
-    '.stl': vtk.vtkSTLReader,
-    '.vtp': vtk.vtkXMLPolyDataReader,
-    '.vts': vtk.vtkXMLStructuredGridReader,
-    '.vtm': vtk.vtkXMLMultiBlockDataReader,
-    '.vtmb': vtk.vtkXMLMultiBlockDataReader,
-    '.case': vtk.vtkGenericEnSightReader,
+    '.vtk': _vtk.vtkDataSetReader,
+    '.pvtk': _vtk.lazy_vtkPDataSetReader,
+    '.vti': _vtk.vtkXMLImageDataReader,
+    '.pvti': _vtk.vtkXMLPImageDataReader,
+    '.vtr': _vtk.vtkXMLRectilinearGridReader,
+    '.pvtr': _vtk.vtkXMLPRectilinearGridReader,
+    '.vtu': _vtk.vtkXMLUnstructuredGridReader,
+    '.pvtu': _vtk.vtkXMLPUnstructuredGridReader,
+    '.ply': _vtk.vtkPLYReader,
+    '.obj': _vtk.vtkOBJReader,
+    '.stl': _vtk.vtkSTLReader,
+    '.vtp': _vtk.vtkXMLPolyDataReader,
+    '.vts': _vtk.vtkXMLStructuredGridReader,
+    '.vtm': _vtk.vtkXMLMultiBlockDataReader,
+    '.vtmb': _vtk.vtkXMLMultiBlockDataReader,
+    '.case': _vtk.vtkGenericEnSightReader,
     # Image formats:
-    '.bmp': vtk.vtkBMPReader,
-    '.dem': vtk.vtkDEMReader,
-    '.dcm': vtk.vtkDICOMImageReader,
-    '.img': vtk.vtkDICOMImageReader,
-    '.jpeg': vtk.vtkJPEGReader,
-    '.jpg': vtk.vtkJPEGReader,
-    '.mhd': vtk.vtkMetaImageReader,
-    '.nrrd': vtk.vtkNrrdReader,
-    '.nhdr': vtk.vtkNrrdReader,
-    '.png': vtk.vtkPNGReader,
-    '.pnm': vtk.vtkPNMReader, # TODO: not tested
-    '.slc': vtk.vtkSLCReader,
-    '.tiff': vtk.vtkTIFFReader,
-    '.tif': vtk.vtkTIFFReader,
+    '.bmp': _vtk.vtkBMPReader,
+    '.dem': _vtk.vtkDEMReader,
+    '.dcm': _vtk.vtkDICOMImageReader,
+    '.img': _vtk.vtkDICOMImageReader,
+    '.jpeg': _vtk.vtkJPEGReader,
+    '.jpg': _vtk.vtkJPEGReader,
+    '.mhd': _vtk.vtkMetaImageReader,
+    '.nrrd': _vtk.vtkNrrdReader,
+    '.nhdr': _vtk.vtkNrrdReader,
+    '.png': _vtk.vtkPNGReader,
+    '.pnm': _vtk.vtkPNMReader, # TODO: not tested
+    '.slc': _vtk.vtkSLCReader,
+    '.tiff': _vtk.vtkTIFFReader,
+    '.tif': _vtk.vtkTIFFReader,
     # Other formats:
-    '.byu': vtk.vtkBYUReader, # TODO: not tested with this extension
-    '.g': vtk.vtkBYUReader,
-    # '.chemml': vtk.vtkCMLMoleculeReader, # TODO: not tested
-    # '.cml': vtk.vtkCMLMoleculeReader, # vtkMolecule is not supported by pyvista
-    # TODO: '.csv': vtk.vtkCSVReader, # vtkTables are currently not supported
-    '.facet': vtk.vtkFacetReader,
-    '.cas': vtk.vtkFLUENTReader, # TODO: not tested
-    # '.dat': vtk.vtkFLUENTReader, # TODO: not working
-    # '.cube': vtk.vtkGaussianCubeReader, # Contains `atom_types` which are note supported?
-    '.res': vtk.vtkMFIXReader, # TODO: not tested
-    '.foam': vtk.vtkOpenFOAMReader,
-    # '.pdb': vtk.vtkPDBReader, # Contains `atom_types` which are note supported?
-    '.p3d': vtk.vtkPlot3DMetaReader,
-    '.pts': vtk.vtkPTSReader,
-    # '.particles': vtk.vtkParticleReader, # TODO: not tested
-    #TODO: '.pht': vtk.vtkPhasta??????,
-    #TODO: '.vpc': vtk.vtkVPIC?????,
-    # '.bin': vtk.vtkMultiBlockPLOT3DReader,# TODO: non-default routine
-    '.tri': vtk.vtkMCubesReader,
-    '.inp': vtk.vtkAVSucdReader,
+    '.byu': _vtk.vtkBYUReader, # TODO: not tested with this extension
+    '.g': _vtk.vtkBYUReader,
+    # '.chemml': _vtk.vtkCMLMoleculeReader, # TODO: not tested
+    # '.cml': _vtk.vtkCMLMoleculeReader, # vtkMolecule is not supported by pyvista
+    # TODO: '.csv': _vtk.vtkCSVReader, # vtkTables are currently not supported
+    '.facet': _vtk.lazy_vtkFacetReader,
+    '.cas': _vtk.vtkFLUENTReader, # TODO: not tested
+    # '.dat': _vtk.vtkFLUENTReader, # TODO: not working
+    # '.cube': _vtk.vtkGaussianCubeReader, # Contains `atom_types` which are note supported?
+    '.res': _vtk.vtkMFIXReader, # TODO: not tested
+    '.foam': _vtk.vtkOpenFOAMReader,
+    # '.pdb': _vtk.vtkPDBReader, # Contains `atom_types` which are note supported?
+    '.p3d': _vtk.lazy_vtkPlot3DMetaReader,
+    '.pts': _vtk.vtkPTSReader,
+    # '.particles': _vtk.vtkParticleReader, # TODO: not tested
+    #TODO: '.pht': _vtk.vtkPhasta??????,
+    #TODO: '.vpc': _vtk.vtkVPIC?????,
+    # '.bin': _vtk.lazy_vtkMultiBlockPLOT3DReader,# TODO: non-default routine
+    '.tri': _vtk.vtkMCubesReader,
+    '.inp': _vtk.vtkAVSucdReader,
 }
 
-VTK_MAJOR = vtk.vtkVersion().GetVTKMajorVersion()
-VTK_MINOR = vtk.vtkVersion().GetVTKMinorVersion()
+VTK_MAJOR = _vtk.vtkVersion().GetVTKMajorVersion()
+VTK_MINOR = _vtk.vtkVersion().GetVTKMinorVersion()
 
 if (VTK_MAJOR >= 8 and VTK_MINOR >= 2):
     try:
-        READERS['.sgy'] = vtk.vtkSegYReader
-        READERS['.segy'] = vtk.vtkSegYReader
+        READERS['.sgy'] = _vtk.lazy_vtkSegYReader
+        READERS['.segy'] = _vtk.lazy_vtkSegYReader
     except AttributeError:
         pass
 
 
+def _get_ext_force(filename, force_ext=None):
+    if force_ext:
+        return str(force_ext).lower()
+    else:
+        return get_ext(filename)
+
+
 def get_ext(filename):
     """Extract the extension of the filename."""
     ext = os.path.splitext(filename)[1].lower()
     return ext
 
 
-def get_reader(filename):
+def get_reader(filename, force_ext=None):
     """Get the corresponding reader based on file extension and instantiates it."""
-    ext = get_ext(filename)
-    return READERS[ext]() # Get and instantiate the reader
+    ext = _get_ext_force(filename, force_ext=force_ext)
+    return READERS[ext]()  # Get and instantiate the reader
 
 
 def set_vtkwriter_mode(vtk_writer, use_binary=True):
     """Set any vtk writer to write as binary or ascii."""
-    if isinstance(vtk_writer, (vtk.vtkDataWriter, vtk.vtkPLYWriter)):
+    if isinstance(vtk_writer, (_vtk.vtkDataWriter, _vtk.vtkPLYWriter, _vtk.vtkSTLWriter)):
         if use_binary:
             vtk_writer.SetFileTypeToBinary()
         else:
             vtk_writer.SetFileTypeToASCII()
-    elif isinstance(vtk_writer, vtk.vtkXMLWriter):
+    elif isinstance(vtk_writer, _vtk.vtkXMLWriter):
         if use_binary:
             vtk_writer.SetDataModeToBinary()
         else:
@@ -118,18 +124,24 @@ def standard_reader_routine(reader, filename, attrs=None):
         The string filename to the data file to read.
 
     attrs : dict, optional
-        A dictionary of attributes to call on the reader. Keys of dictionary are
-        the attribute/method names and values are the arguments passed to those
-        calls. If you do not have any attributes to call, pass ``None`` as the
-        value.
+        A dictionary of attributes to call on the reader. Keys of
+        dictionary are the attribute/method names and values are the
+        arguments passed to those calls. If you do not have any
+        attributes to call, pass ``None`` as the value.
 
     """
+    observer = pyvista.utilities.errors.Observer()
+    observer.observe(reader)
+
     if attrs is None:
         attrs = {}
     if not isinstance(attrs, dict):
         raise TypeError('Attributes must be a dictionary of name and arguments.')
     if filename is not None:
-        reader.SetFileName(filename)
+        try:
+            reader.SetCaseFileName(filename)
+        except AttributeError:
+            reader.SetFileName(filename)
     # Apply any attributes listed
     for name, args in attrs.items():
         attr = getattr(reader, name)
@@ -141,12 +153,20 @@ def standard_reader_routine(reader, filename, attrs=None):
             attr()
     # Perform the read
     reader.Update()
-    return pyvista.wrap(reader.GetOutputDataObject(0))
+
+    # Check reader for errors
+    if observer.has_event_occurred():
+        warnings.warn(f'The VTK reader `{reader.GetClassName()}` raised an error while reading the file.\n'
+                      f'\t"{observer.get_message()}"')
+
+    data = pyvista.wrap(reader.GetOutputDataObject(0))
+    data._post_file_load_processing()
+    return data
 
 
 def read_legacy(filename):
     """Use VTK's legacy reader to read a file."""
-    reader = vtk.vtkDataSetReader()
+    reader = _vtk.vtkDataSetReader()
     reader.SetFileName(filename)
     # Ensure all data is fetched with poorly formatted legacy files
     reader.ReadAllScalarsOn()
@@ -161,7 +181,7 @@ def read_legacy(filename):
     return output
 
 
-def read(filename, attrs=None, file_format=None):
+def read(filename, attrs=None, force_ext=None, file_format=None):
     """Read any VTK file.
 
     It will figure out what reader to use then wrap the VTK object for
@@ -180,6 +200,11 @@ def read(filename, attrs=None, file_format=None):
         arguments passed to those calls. If you do not have any
         attributes to call, pass ``None`` as the value.
 
+    force_ext: str, optional
+        If specified, the reader will be chosen by an extension which
+        is different to its actual extension. For example, ``'.vts'``,
+        ``'.vtu'``.
+
     file_format : str, optional
         Format of file to read with meshio.
 
@@ -199,6 +224,9 @@ def read(filename, attrs=None, file_format=None):
 
     >>> mesh = pyvista.read("mesh.obj")  # doctest:+SKIP
     """
+    if file_format is not None and force_ext is not None:
+        raise ValueError('Only one of `file_format` and `force_ext` may be specified.')
+
     if isinstance(filename, (list, tuple)):
         multi = pyvista.MultiBlock()
         for each in filename:
@@ -212,7 +240,8 @@ def read(filename, attrs=None, file_format=None):
     filename = os.path.abspath(os.path.expanduser(str(filename)))
     if not os.path.isfile(filename):
         raise FileNotFoundError(f'File ({filename}) not found')
-    ext = get_ext(filename)
+
+    ext = _get_ext_force(filename, force_ext)
 
     # Read file using meshio.read if file_format is present
     if file_format:
@@ -220,33 +249,24 @@ def read(filename, attrs=None, file_format=None):
 
     # From the extension, decide which reader to use
     if attrs is not None:
-        reader = get_reader(filename)
+        reader = get_reader(filename, force_ext=ext)
         return standard_reader_routine(reader, filename, attrs=attrs)
-    elif ext in '.vti': # ImageData
-        return pyvista.UniformGrid(filename)
-    elif ext in '.vtr': # RectilinearGrid
-        return pyvista.RectilinearGrid(filename)
-    elif ext in '.vtu': # UnstructuredGrid
-        return pyvista.UnstructuredGrid(filename)
-    elif ext in ['.ply', '.obj', '.stl']: # PolyData
-        return pyvista.PolyData(filename)
-    elif ext in '.vts': # StructuredGrid
-        return pyvista.StructuredGrid(filename)
-    elif ext in ['.vtm', '.vtmb', '.case']:
-        return pyvista.MultiBlock(filename)
     elif ext in ['.e', '.exo']:
         return read_exodus(filename)
     elif ext in ['.vtk']:
         # Attempt to use the legacy reader...
         return read_legacy(filename)
-    elif ext in ['.jpeg', '.jpg']:
-        return pyvista.Texture(filename).to_image()
     else:
         # Attempt find a reader in the readers mapping
         try:
-            reader = get_reader(filename)
+            reader = get_reader(filename, force_ext=ext)
             return standard_reader_routine(reader, filename)
         except KeyError:
+            # Don't fall back to meshio if using `force_ext`, which is really
+            # just intended to be used with the native PyVista readers
+            if force_ext is not None:
+                from meshio._exceptions import ReadError
+                raise ReadError
             # Attempt read with meshio
             try:
                 from meshio._exceptions import ReadError
@@ -282,15 +302,67 @@ def read_exodus(filename,
                 animate_mode_shapes=True,
                 apply_displacements=True,
                 displacement_magnitude=1.0,
+                read_point_data=True,
+                read_cell_data=True,
                 enabled_sidesets=None):
-    """Read an ExodusII file (``'.e'`` or ``'.exo'``)."""
-    reader = vtk.vtkExodusIIReader()
+    """Read an ExodusII file (``'.e'`` or ``'.exo'``).
+
+    Parameters
+    ----------
+    filename : str
+        The path to the exodus file to read.
+
+    animate_mode_shapes : bool, optional
+        When ``True`` then this reader will report a continuous time
+        range [0,1] and animate the displacements in a periodic
+        sinusoid.
+
+    apply_displacements : bool, optional
+        Geometric locations can include displacements. When ``True``,
+        the nodal positions are 'displaced' by the standard exodus
+        displacement vector. If displacements are turned off, the user
+        can explicitly add them by applying a warp filter.
+
+    displacement_magnitude : bool, optional
+        This is a number between 0 and 1 that is used to scale the
+        ``DisplacementMagnitude`` in a sinusoidal pattern.
+
+    read_point_data : bool, optional
+        Read in data associated with points.  Default ``True``.
+
+    read_cell_data : bool, optional
+        Read in data associated with cells.  Default ``True``.
+
+    enabled_sidesets : str or int, optional
+        The name of the array that store the mapping from side set
+        cells back to the global id of the elements they bound.
+
+    Examples
+    --------
+    >>> import pyvista as pv
+    >>> from pyvista import examples
+    >>> data = read_exodus('mymesh.exo')  # doctest:+SKIP
+
+    """
+    # lazy import here to avoid loading module on import pyvista
+    try:
+        from vtkmodules.vtkIOExodus import vtkExodusIIReader
+    except ImportError:
+        from vtk import vtkExodusIIReader
+
+    reader = vtkExodusIIReader()
     reader.SetFileName(filename)
     reader.UpdateInformation()
     reader.SetAnimateModeShapes(animate_mode_shapes)
     reader.SetApplyDisplacements(apply_displacements)
     reader.SetDisplacementMagnitude(displacement_magnitude)
 
+    if read_point_data:  # read in all point data variables
+        reader.SetAllArrayStatus(vtkExodusIIReader.NODAL, 1)
+
+    if read_cell_data:  # read in all cell data variables
+        reader.SetAllArrayStatus(vtkExodusIIReader.ELEM_BLOCK, 1)
+
     if enabled_sidesets is None:
         enabled_sidesets = list(range(reader.GetNumberOfSideSetArrays()))
 
@@ -310,25 +382,26 @@ def read_exodus(filename,
 
 def read_plot3d(filename, q_filenames=(), auto_detect=True, attrs=None):
     """Read a Plot3D grid file (e.g., grid.in) and optional q file(s).
-    
+
     Parameters
     ----------
     filename : str
         The string filename to the data file to read.
 
     q_filenames : str or tuple(str), optional
-        The string filename of the q-file, or iterable of such filenames.
+        The string filename of the q-file, or iterable of such
+        filenames.
 
     auto_detect : bool, optional
-        When this option is turned on, the reader will try to figure out the
-        values of various options such as byte order, byte count etc. Default is
-        True.
+        When this option is turned on, the reader will try to figure
+        out the values of various options such as byte order, byte
+        count etc. Default is ``True``.
 
     attrs : dict, optional
-        A dictionary of attributes to call on the reader. Keys of dictionary are
-        the attribute/method names and values are the arguments passed to those
-        calls. If you do not have any attributes to call, pass ``None`` as the
-        value.
+        A dictionary of attributes to call on the reader. Keys of
+        dictionary are the attribute/method names and values are the
+        arguments passed to those calls. If you do not have any
+        attributes to call, pass ``None`` as the value.
 
     Returns
     -------
@@ -338,7 +411,7 @@ def read_plot3d(filename, q_filenames=(), auto_detect=True, attrs=None):
     """
     filename = _process_filename(filename)
 
-    reader = vtk.vtkMultiBlockPLOT3DReader()
+    reader = _vtk.lazy_vtkMultiBlockPLOT3DReader()
     reader.SetFileName(filename)
 
     # q_filenames may be a list or a single filename
@@ -386,7 +459,7 @@ def from_meshio(mesh):
             np.hstack((np.full((len(c.data), 1), numnodes), c.data)).ravel()
         )
         cell_type += [vtk_type] * len(c.data)
-        if not VTK9:
+        if not _vtk.VTK9:
             offset += [next_offset + i * (numnodes + 1) for i in range(len(c.data))]
             next_offset = offset[-1] + numnodes + 1
 
@@ -398,7 +471,7 @@ def from_meshio(mesh):
     if points.shape[1] == 2:
         points = np.hstack((points, np.zeros((len(points), 1))))
 
-    if VTK9:
+    if _vtk.VTK9:
         grid = pyvista.UnstructuredGrid(
             np.concatenate(cells),
             np.array(cell_type),
@@ -418,6 +491,9 @@ def from_meshio(mesh):
     # Set cell data
     grid.cell_arrays.update(cell_data)
 
+    # Call datatype-specific post-load processing
+    grid._post_file_load_processing()
+
     return grid
 
 
@@ -431,13 +507,14 @@ def read_meshio(filename, file_format=None):
     return from_meshio(mesh)
 
 
-def save_meshio(filename, mesh, file_format = None, **kwargs):
+def save_meshio(filename, mesh, file_format=None, **kwargs):
     """Save mesh to file using meshio.
 
     Parameters
     ----------
-    mesh : pyvista.Common
+    mesh : pyvista.DataSet
         Any PyVista mesh/spatial data type.
+
     file_format : str
         File type for meshio to save.
 
@@ -468,7 +545,7 @@ def save_meshio(filename, mesh, file_format = None, **kwargs):
     c = 0
     for offset, cell_type in zip(vtk_offset, vtk_cell_type):
         numnodes = vtk_cells[offset+c]
-        if VTK9:  # must offset by cell count
+        if _vtk.VTK9:  # must offset by cell count
             cell = vtk_cells[offset+1+c:offset+1+c+numnodes]
             c += 1
         else:
@@ -516,4 +593,4 @@ def save_meshio(filename, mesh, file_format = None, **kwargs):
     )
 
 def _process_filename(filename):
-    return os.path.abspath(os.path.expanduser(str(filename)))
\ No newline at end of file
+    return os.path.abspath(os.path.expanduser(str(filename)))
