@@ -23,11 +23,16 @@ def start_xvfb(wait=3, window_size=None):
         to disable wait.
 
     window_size : list, optional
-        Window size of the virtual frame buffer.  Defaults to the
-        default window size in ``rcParams``.
+        Window size of the virtual frame buffer.  Defaults to
+        ``pyvista.global_theme.window_size``.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> pyvista.start_xvfb()  # doctest:+SKIP
 
     """
-    from pyvista import rcParams
+    from pyvista import global_theme
 
     if os.name != 'posix':
         raise OSError('`start_xvfb` is only supported on Linux')
@@ -36,7 +41,9 @@ def start_xvfb(wait=3, window_size=None):
         raise OSError(XVFB_INSTALL_NOTES)
 
     # use current default window size
-    window_size_parm = '%dx%dx24' % tuple(rcParams['window_size'])
+    if window_size is None:
+        window_size = global_theme.window_size
+    window_size_parm = f'{window_size[0]:d}x{window_size[1]:d}x24'
     display_num = ':99'
     os.system(f'Xvfb {display_num} -screen 0 {window_size_parm} > /dev/null 2>&1 &')
     os.environ['DISPLAY'] = display_num
